<?php
/**
 * About us Template options
 *
 * @package Theme Palace
 * @subpackage Loud Pro
 * @since Loud Pro 1.0
 */

// Add About us portfolio section
$wp_customize->add_section( 'loud_pro_about_portfolio_section', array(
	'title'             => esc_html__( 'Portfolio Section','loud-pro' ),
	'description'       => esc_html__( 'Portfolio Section options.', 'loud-pro' ),
	'panel'             => 'loud_pro_about_us_panel',
) );

// Portfolio content enable control and setting
$wp_customize->add_setting( 'loud_pro_theme_options[portfolio_section_enable]', array(
	'default'			=> 	$options['portfolio_section_enable'],
	'sanitize_callback' => 'loud_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Loud_Pro_Switch_Control( $wp_customize, 'loud_pro_theme_options[portfolio_section_enable]', array(
	'label'             => esc_html__( 'Portfolio Section Enable', 'loud-pro' ),
	'section'           => 'loud_pro_about_portfolio_section',
	'on_off_label' 		=> loud_pro_enable_options(),
) ) );

// Portfolio content type control and setting
$wp_customize->add_setting( 'loud_pro_theme_options[portfolio_note_content_type]', array(
	'default'          	=> $options['portfolio_note_content_type'],
	'sanitize_callback' => 'loud_pro_sanitize_select',
) );

$wp_customize->add_control( 'loud_pro_theme_options[portfolio_note_content_type]', array(
	'label'             => esc_html__( 'Portfolio Introduction Type', 'loud-pro' ),
	'section'           => 'loud_pro_about_portfolio_section',
	'type'				=> 'select',
	'active_callback' 	=> 'loud_pro_is_portfolio_section_enable',
	'choices'			=> array( 
		'demo' 		=> esc_html__( 'Demo', 'loud-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'loud-pro' ),
		'page' 		=> esc_html__( 'Page', 'loud-pro' ),
		'post' 		=> esc_html__( 'Post', 'loud-pro' ),
	),
) );

// Show page drop-down setting and control
$wp_customize->add_setting( 'loud_pro_theme_options[portfolio_note_content_page]', array(
	'sanitize_callback' => 'loud_pro_sanitize_page'
) );

$wp_customize->add_control( 'loud_pro_theme_options[portfolio_note_content_page]', array(
	'label'           	=> esc_html__( 'Select Page', 'loud-pro' ),
	'section'        	=> 'loud_pro_about_portfolio_section',
	'active_callback' 	=> 'loud_pro_is_portfolio_note_content_page',
	'type'				=> 'dropdown-pages'
) );

// portfolio Section content type post setting and control.
$wp_customize->add_setting( 'loud_pro_theme_options[portfolio_note_content_post]', array(
	'validate_callback' => 'loud_pro_validate_post_id',
	'sanitize_callback' => 'loud_pro_sanitize_single_post_id',
) );

$wp_customize->add_control( 'loud_pro_theme_options[portfolio_note_content_post]', array(
	'active_callback'	=> 'loud_pro_is_portfolio_note_content_post',
	'label'             => esc_html__( 'Input Post Id', 'loud-pro' ),
	'description'       => esc_html__( 'Please Input Valid Post Id. Simply hover post title on dashboard to see the Post ID.', 'loud-pro' ),
	'section'           => 'loud_pro_about_portfolio_section',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'style'	=> 'width:100px',
		),
) );

// portfolio title setting and control
$wp_customize->add_setting( 'loud_pro_theme_options[portfolio_note_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['portfolio_note_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'loud_pro_theme_options[portfolio_note_title]', array(
	'label'           	=> esc_html__( 'Title', 'loud-pro' ),
	'section'        	=> 'loud_pro_about_portfolio_section',
	'active_callback' 	=> 'loud_pro_is_portfolio_note_content_custom',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'loud_pro_theme_options[portfolio_note_title]', array(
		'selector'            => '#movies-list .wrapper .entry-header h2.entry-title',
		'settings'            => 'loud_pro_theme_options[portfolio_note_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'loud_pro_portfolio_title_partial',
    ) );
}

// About us description setting and control
$wp_customize->add_setting( 'loud_pro_theme_options[portfolio_note_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'          	=> $options['portfolio_note_description'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'loud_pro_theme_options[portfolio_note_description]', array(
	'label'           	=> esc_html__( 'Description', 'loud-pro' ),
	'section'        	=> 'loud_pro_about_portfolio_section',
	'active_callback' 	=> 'loud_pro_is_portfolio_note_content_custom',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'loud_pro_theme_options[portfolio_note_description]', array(
		'selector'            => '#movies-list .wrapper .entry-content',
		'settings'            => 'loud_pro_theme_options[portfolio_note_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'loud_pro_portfolio_description_partial',
    ) );
}

// Portfolio content type control and setting
$wp_customize->add_setting( 'loud_pro_theme_options[portfolio_content_type]', array(
	'default'          	=> $options['portfolio_content_type'],
	'sanitize_callback' => 'loud_pro_sanitize_select',
) );

$wp_customize->add_control( 'loud_pro_theme_options[portfolio_content_type]', array(
	'label'             => esc_html__( 'Portfolio Content Type', 'loud-pro' ),
	'section'           => 'loud_pro_about_portfolio_section',
	'type'				=> 'select',
	'active_callback' 	=> 'loud_pro_is_portfolio_section_enable',
	'choices'			=> array( 
		'demo' 		=> esc_html__( 'Demo', 'loud-pro' ),
		'category' 	=> esc_html__( 'Category', 'loud-pro' ),
		'page' 		=> esc_html__( 'Page', 'loud-pro' ),
		'post' 		=> esc_html__( 'Post', 'loud-pro' ),
	),
) );

// Portfolio number control and setting
$wp_customize->add_setting( 'loud_pro_theme_options[portfolio_count]', array(
	'default'          	=> $options['portfolio_count'],
	'sanitize_callback' => 'loud_pro_sanitize_number_range',
	'validate_callback' => 'loud_pro_validate_no_of_portfolio',
) );

$wp_customize->add_control( 'loud_pro_theme_options[portfolio_count]', array(
	'label'             => esc_html__( 'Number of Portfolio', 'loud-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then referesh the page to see the change.', 'loud-pro' ),
	'section'           => 'loud_pro_about_portfolio_section',
	'active_callback'   => 'loud_pro_is_portfolio_content_not_demo',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'loud_pro_theme_options[portfolio_content_category]', array(
	'sanitize_callback' => 'loud_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Loud_Pro_Dropdown_Taxonomies_Control( $wp_customize,'loud_pro_theme_options[portfolio_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'loud-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'loud-pro' ),
	'section'           => 'loud_pro_about_portfolio_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'loud_pro_is_portfolio_content_category'
) ) );

// Portfolio Section content type post setting and control.
$wp_customize->add_setting( 'loud_pro_theme_options[portfolio_content_post]', array(
	'sanitize_callback' => 'loud_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'loud_pro_theme_options[portfolio_content_post]', array(
	'active_callback'	=> 'loud_pro_is_portfolio_content_post',
	'label'             => esc_html__( 'Input Post Ids', 'loud-pro' ),
	'description'       => esc_html__( 'Simply hover post title on dashboard to see the Post ID. Max no. of posts allowed is 10. ie: 11, 24, 34', 'loud-pro' ),
	'section'           => 'loud_pro_about_portfolio_section',
	'type'				=> 'text',
) );

for ( $i = 1; $i <= $options['portfolio_count']; $i++ ) {
	// Show page drop-down setting and control
	$wp_customize->add_setting( 'loud_pro_theme_options[portfolio_content_page_' . $i . ']', array(
		'sanitize_callback' => 'loud_pro_sanitize_page'
	) );

	$wp_customize->add_control( 'loud_pro_theme_options[portfolio_content_page_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Select Page %d', 'loud-pro' ), $i ),
		'section'        	=> 'loud_pro_about_portfolio_section',
		'active_callback' 	=> 'loud_pro_is_portfolio_content_page',
		'type'				=> 'dropdown-pages'
	) );
}