<?php
/**
 * Quotation Section options
 *
 * @package Theme Palace
 * @subpackage Loud Pro
 * @since Loud Pro 1.0
 */

// Add Quotation section
$wp_customize->add_section( 'loud_pro_quotation_section', array(
	'title'             => esc_html__( 'Quotation Section','loud-pro' ),
	'description'       => esc_html__( 'Quotation Section options.', 'loud-pro' ),
	'panel'             => 'loud_pro_front_page_panel',
) );

// Quotation content enable control and setting
$wp_customize->add_setting( 'loud_pro_theme_options[quotation_section_enable]', array(
	'default'			=> 	$options['quotation_section_enable'],
	'sanitize_callback' => 'loud_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Loud_Pro_Switch_Control( $wp_customize, 'loud_pro_theme_options[quotation_section_enable]', array(
	'label'             => esc_html__( 'Quotation Section Enable', 'loud-pro' ),
	'section'           => 'loud_pro_quotation_section',
	'on_off_label' 		=> loud_pro_enable_options(),
) ) );

// Featurd content type control and setting
$wp_customize->add_setting( 'loud_pro_theme_options[quotation_content_type]', array(
	'default'          	=> $options['quotation_content_type'],
	'sanitize_callback' => 'loud_pro_sanitize_select',
) );

$wp_customize->add_control( 'loud_pro_theme_options[quotation_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'loud-pro' ),
	'section'           => 'loud_pro_quotation_section',
	'type'				=> 'select',
	'active_callback' 	=> 'loud_pro_is_quotation_section_enable',
	'choices'			=> array( 
		'demo' 			=> esc_html__( 'Demo', 'loud-pro' ),
		'category' 		=> esc_html__( 'Category', 'loud-pro' ),
		'post' 			=> esc_html__( 'Post', 'loud-pro' ),
		'page' 			=> esc_html__( 'Page', 'loud-pro' ),
		'custom' 		=> esc_html__( 'Custom', 'loud-pro' ),
	),
) );

// Quotation number control and setting
$wp_customize->add_setting( 'loud_pro_theme_options[quotation_count]', array(
	'default'          	=> $options['quotation_count'],
	'sanitize_callback' => 'loud_pro_sanitize_number_range',
	'validate_callback' => 'loud_pro_validate_no_of_quotation',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'loud_pro_theme_options[quotation_count]', array(
	'label'             => esc_html__( 'Number of Quotation', 'loud-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 5. Please input the valid number and save. Then refresh the page to see the change.', 'loud-pro' ),
	'section'           => 'loud_pro_quotation_section',
	'active_callback'   => 'loud_pro_is_quotation_section_content_count_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 5,
		'style' => 'width: 100px;'
		),
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'loud_pro_theme_options[quotation_content_category]', array(
	'sanitize_callback' => 'loud_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Loud_Pro_Dropdown_Taxonomies_Control( $wp_customize,'loud_pro_theme_options[quotation_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'loud-pro' ),
	'description'      	=> esc_html__( 'Note: Latest assigned number of quotation post\'s content will be shown from selected category', 'loud-pro' ),
	'section'           => 'loud_pro_quotation_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'loud_pro_is_quotation_section_content_category_enable'
) ) );

// Quotation posts Section content type post setting and control.
$wp_customize->add_setting( 'loud_pro_theme_options[quotation_content_post]', array(
	'sanitize_callback' => 'loud_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'loud_pro_theme_options[quotation_content_post]', array(
	'active_callback'	=> 'loud_pro_is_quotation_section_content_post_enable',
	'label'             => esc_html__( 'Input Post Ids', 'loud-pro' ),
	'description'       => esc_html__( 'Note: Post\'s content will be shown from selected posts. Simply hover post title on dashboard to see the Post ID. Max no. of posts allowed is 5. ie: 11, 24, 34', 'loud-pro' ),
	'section'           => 'loud_pro_quotation_section',
	'type'				=> 'text',
) );

for ( $i = 1; $i <= $options['quotation_count']; $i++ ) {
	// Show page drop-down setting and control
	$wp_customize->add_setting( 'loud_pro_theme_options[quotation_content_page' . $i . ']', array(
		'sanitize_callback' => 'loud_pro_sanitize_page'
	) );

	$wp_customize->add_control( 'loud_pro_theme_options[quotation_content_page' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Select Page %d', 'loud-pro' ), $i ),
		'description'       => esc_html__( 'Note: Page\'s content will be shown from selected page', 'loud-pro' ),
		'section'        	=> 'loud_pro_quotation_section',
		'active_callback' 	=> 'loud_pro_is_quotation_section_content_page_enable',
		'type'				=> 'dropdown-pages'
	) );

	// custom quotation setting and control
	$wp_customize->add_setting( 'loud_pro_theme_options[quotation_content_custom_' . $i . ']', array(
		'default' 			=> $options['quotation_content_custom'],
		'sanitize_callback' => 'wp_kses_post',
	) );

	$wp_customize->add_control( 'loud_pro_theme_options[quotation_content_custom_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Quotation %d', 'loud-pro' ), $i ),
		'section'        	=> 'loud_pro_quotation_section',
		'active_callback' 	=> 'loud_pro_is_quotation_section_content_custom_enable',
		'type'				=> 'textarea',
	) );
}